class BlockReuseSettingsController < ApplicationController
  model_data_store(BlockReuseSetting)

  def update
    params = model_params

    block_discard_after = params[:block_discard_after].to_i
    block_wash_after = params[:block_wash_after].to_i
    server_port = params[:server_port].to_i
    enable_server = params[:enable_server]

    settings = BlockReuseSetting.first
    old_block_wash_after = settings.block_wash_after
    old_block_discard_after = settings.block_discard_after

    if settings.nil? || enable_server.nil? || server_port <= 0 || block_discard_after <= 0 || block_wash_after <= 0
      return render json: {error: "error while saving settings"}, status: :unprocessable_entity
    end

    block_wash_after_diff = block_wash_after - settings.block_wash_after
    block_discard_after_diff = block_discard_after - settings.block_discard_after

    settings.update(enable_server: enable_server, server_port: server_port, block_wash_after: block_wash_after, block_discard_after: block_discard_after)

    # If the reuse server was on and is being disabled, stop it
    if !enable_server && BlockReuseServer.instance.online?
      BlockReuseServer.instance.stop
    end

    # If the block discard/wash count changes, update the existing blocks
    if block_wash_after_diff != 0 || block_discard_after_diff != 0
      settings.adjust_blocks(old_block_wash_after, old_block_discard_after)
    end

    render :show
  end

  def start_server
    settings = BlockReuseSetting.first

    if settings.enable_server && settings.server_port
      begin
        BlockReuseServer.instance.start(settings.server_port)
        @model = BlockReuseSetting.first
        render :show
      rescue => err
        render json: {error: "unable to start server - #{err}"}, status: :internal_server_error
      end
    else
      render json: {error: "unable to start server - invalid settings."}, status: :unprocessable_entity
    end
  end

  def stop_server
    begin
      BlockReuseServer.instance.stop
      @model = BlockReuseSetting.first
      render :show
    rescue => err
      render json: {error: "unable to stop server - #{err}"}, status: :internal_server_error
    end
  end

  private

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:block_reuse_setting).permit(:enable_server, :server_port, :block_wash_after, :block_discard_after)
  end
end
