module DataExportApi
  class V1::ExternalApiController < ApiController
    def job_states
      def filters
        {
          time: {
            column: "time",
            required: true,
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          },
          sn: {
            column: "machine.sn",
            param: :sn,
            required_combination: [:job]
          },
          job: {
            column: "job.number",
            param: :job,
            required_combination: [:sn]
          },
          state: {
            column: "state",
            param: :state,
          },
          side: {
            column: "job.side",
            param: :side,
          },
          process: {
            column: "process",
            param: :process,
          }
        }
      end

      def order_column
        "time"
      end

      def selected_columns
        %w[jobs.number jobs.side state substate process comment scrap scrap_reason time machines.sn]
      end

      def return_data_root
        :job_states
      end

      set_model(JobState.joins(:machine).joins(:job))

      do_query
    end

    def machine_states
      def filters
        {
          time: {
            column: "time",
            required: true,
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          },
          sn: {
            column: "machine.sn",
            param: :sn,
          },
          state: {
            column: "state",
            param: :state,
          }
        }
      end

      def selected_columns
        %w[machine_sn state calculated_duration time comment addon]
      end

      def order_column
        "time"
      end

      def return_data_root
        :machine_states
      end

      set_model(MachineState.joins(:machine))

      do_query
    end

    def process_params
      def filters
        {
          time: {
            column: "time",
            required: true,
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          },
          sn: {
            column: "machine.sn",
            param: :sn,
            required_combination: [:job]
          },
          job: {
            column: "job.number",
            param: :job,
            required_combination: [:sn]
          },
          side: {
            column: "job.side",
            param: :side,
          },
          param: {
            column: "job_process_parameters.name",
            param: :param,
          }
        }
      end

      def selected_columns
        %w[job_processes.id jobs.number job_processes.side machines.sn job_processes.time job_process_parameters.name job_process_parameters.value]
      end

      def order_column
        "time"
      end

      def return_data_root
        :process_params
      end

      set_model(JobProcess.joins(:job, :machine, :job_process_parameters))
      group_by("id")
      aggregate('params', %w[name value])
      do_query
    end

    def machine_errors
      def filters
        {
          time: {
            column: "time",
            required: true,
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          },
          sn: {
            column: "machine.sn",
            param: :sn,
            required: true
          },
          job: {
            column: "job.number",
            param: :job
          },
          errno: {
            column: "errno",
            param: :errno
          },
          errortype: {
            column: "errortype",
            param: :errortype
          },
          status: {
            column: "status",
            param: :status
          }
        }
      end

      def selected_columns
        ['machines.sn', {column: 'jobs.number', return_name: 'job'}, 'jobs.side', 'time', 'errno', 'error', 'errortype', 'status', 'piececounter']
      end

      def order_column
        "time"
      end

      def return_data_root
        :machine_errors
      end

      #Left outer join since some errors dont need jobs
      set_model(Error.joins(:machine).left_outer_joins(:job))

      do_query
    end

    def lens_attribute
      def filters
        {
          time: {
            column: "created_at",
            required_combination: [:job],
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          },
          job: {
            column: "number",
            param: :job,
            required_combination: [:time]
          },
          side: {
            column: "side",
            param: :side,
          },
          param: {
            column: "job_data.name",
            param: :attribute,
          }
        }
      end

      def selected_columns
        ['id', {column: 'number', return_name: 'job'}, 'side', {column: 'created_at', return_name: 'time'}, 'job_data.name', 'job_data.value']
      end

      def order_column
        "job_data.created_at"
      end

      def return_data_root
        :lens
      end

      set_model(Job.left_outer_joins(:job_data))

      group_by('id')
      aggregate('attribute', %w[name value])
      do_query
    end

    def block_pieces
      def filters
        {
          time: {
            column: "updated_at",
            required: true,
            range: {
              lower_bound: {
                param: :start,
              },
              upper_bound: {
                param: :end
              }
            }
          }
        }
      end

      def selected_columns
        ['dmc', {column: 'usage_count', return_name: 'usecount'}, {column: 'updated_at', return_name: 'time'}]
      end

      def order_column
        'updated_at'
      end

      def return_data_root
        :blocks
      end

      set_model(Block)

      do_query
    end
  end
end



