class ErrorFiltersController < ApplicationController
  def self.set_target_before
    super + [:toggle]
  end

  model_data_store(ErrorFilter, {create: true, read: true, update: true, delete: false, index: true}, {create: true, read: true, update: true, delete: false, index: true})

  class InvalidErrorFilterTarget < StandardError; end

  def before_filter(filter)
    if filter[:id] == 'system_default' || filter[:id] == 'filter_target_id'
      filter[:strict_match] = true
    end
    filter
  end

  def toggle
    @model.toggle(:enabled)
    if @model.save
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def destroy
    Rails::logger.warn "Cannot delete an Error Filter from Rx-Data"
    render json: {error: "Error filters cannot be deleted."}, status: :unprocessable_entity
  end

  private

  # Only allow a list of trusted parameters through.
  def model_params
    filter = params.require(:error_filter).permit(:name, :error_codes, :behaviour, :replace_name, :group_code, :filter_target_id, :filter_target_type)

    target = MachineGroup.find_by_id(filter[:filter_target_id]) if filter[:filter_target_type] == 'MachineGroup'
    raise InvalidErrorFilterTarget if target.nil?

    {
      name: filter[:name],
      error_codes: filter[:error_codes].gsub(/\s+/, ""),
      behaviour: filter[:behaviour],
      replace_name: filter[:replace_name],
      group_code: filter[:group_code],
      filter_target: target
    }
  end
end
