class JobProcessParametersController < ApplicationController
  include MachineResponse
  include MachineDataViewFilter
  include RxModule::Tableable

  wrap_parameters :job_process_parameter, include: [:job, :lensside, :process, :batchId, :params]

  model_data_store(JobProcessParameter)

  def before_set_targets
    models = if filters["sn"]
      JobProcessParameter.joins(:job_process => :machine).where(job_processes: {machines: {sn: filters["sn"]}})
    else
      JobProcessParameter.joins(:job_process)
    end
    view_before_set_targets(models, params, "job_processes")
  end

  def before_filter(filter)
    view_before_filter(filter)
  end

  def add
    begin
      AddJobProcessJob.perform_later(add_params, job_process_params)
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  private

  def job_process_params
    params.require(:job_process_parameter).permit(params: [param: [:name, :value]])[:params][:param]
  end

  def add_params
    params[:job_process_parameter] = params[:processparameter] if params[:processparameter]
    job_process = params.require(:job_process_parameter).permit(:job, :lensside, :batchId)

    machine = Machine.find_or_create_by(sn: params[:sn])

    # If there is no job number in the payload, use the batchId instead
    # Note, this solution is only to be applied until batching of jobs is properly implemented (http://omics.dyndns.biz:4747/rx-suite/modules/optional/data/-/issues/40)
    side_num = Sideable.side_letter_to_side_num(job_process[:lensside])
    job_number = job_process[:job] || job_process[:batchId]
    job = FindHelpers::JobFinders.find_active_or_create_by_number_and_side_num(job_number, side_num)

    manufacturing_process = ManufacturingProcess.get_by_job_and_name(job.id, params[:job_process_parameter][:process])
    {
      job_id: job.id,
      side: side_num,
      manufacturing_process: manufacturing_process,
      batch_id: job_process[:batchId],
      machine_id: machine.id,
      time: "#{params[:date]} #{params[:time]}"
    }
  end
end
