class JobStatesController < ApplicationController
  include MachineResponse
  include MachineDataViewFilter
  include RxModule::Tableable
  include DataHelpers

  def self.set_target_before
    super + [:process_params]
  end

  wrap_parameters :job_state, include: [:job, :job_id, :machine_id, :batchId, :lensside, :substate, :state, :process, :comment, :scrap, :scrapReason]
  model_data_store(JobState)

  # PATCH/PUT /jobstate/1.0/add
  def add
    begin
      AddJobState.perform_later(job_state_add_params(params))
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  def add_bulk
    begin
      AddBulkJobState.perform_later(job_state_add_bulk_params(params))
    rescue => e
      Rails.logger.error e
    end
    send_machine_response
  end

  def process_params
    render :process_params
  end

  def before_set_targets
    machine_sn = filters["sn"]
    models = if machine_sn
      @models.where(machine: Machine.find_by(sn: machine_sn))
    else
      @models
    end
    models.includes(machine: :machine_groups, job: [])
    models = models.eager_load(:job)
    view_before_set_targets(models, params)
  end

  def before_filter(filter)
    if filter["id"] == "job_number"
      filter["id"] = "jobs.number"
    end
    view_before_filter(filter)
  end

  def before_sort(sort)
    if sort["id"] == "job_number"
      sort["id"] = "jobs.number"
    end
    if sort["id"] == "side"
      sort["id"] = "job_states.side"
    end
    sort
  end

  private

  def job_state_add_bulk_params(params)
    {
      should_broadcast: params[:should_broadcast],
      job_states: params[:jobStates].map do |payload|
        searchParams = payload[:searchParams]
        job_state_data = payload[:jobState]
        side_num = Sideable.side_letter_to_side_num(job_state_data[:lensside])
        {
          machine: Machine.find_or_create_by(sn: searchParams[:sn]),
          time: "#{searchParams[:date]} #{searchParams[:time]}",
          job: FindHelpers::JobFinders.find_active_or_create_by_number_and_side_num(job_state_data[:job], side_num),
          side: side_num,
          state: job_state_data[:state].downcase,
          comment: job_state_data[:comment],
          scrap_reason: job_state_data[:scrapReason],
          substate: job_state_data[:substate],
          process: job_state_data[:process],
        }
      end
    }
  end
end
