class ProductionSettingsController < ApplicationController
  model_data_store(ProductionSetting, {create: false, read: true, update: true, delete: false, index: false}, {create: false, read: true, update: true, delete: false, index: false})

  def update
    params = model_params

    # If we're using simplified machine states, change the colors to reflect this as well
    if @model.simplified_machine_states != params[:simplified_machine_states]
      if params[:simplified_machine_states]
        Color.apply_simplified_colors
      else
        Color.apply_default_colors
      end
    end

    if @model.update(params)
      render json: @model, status: :ok, location: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end


  def register_as_eer_lab
    @model = ProductionSetting.instance
    if @model.update(is_eer_lab: true)
      render :show
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  private

  # Only allow a list of trusted parameters through.
  def model_params
    params.require(:production_setting).permit(:throughput_metric,
                                               :machine_oee_target,
                                               :machine_utilization_target,
                                               :machine_uptime_target,
                                               :simplified_machine_states,
                                               :tx_tolerance,
                                               :ty_tolerance,
                                               :rz_tolerance)
  end
end
