import * as React from "react";
import {InputField, PaddedPaper} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {Trans} from '@lingui/macro';
import {Button, CircularProgress, Grid, makeStyles} from "@material-ui/core";
import {SyntheticEvent} from "react";

type OperatorSearchFieldProps = {
    searchFunction: (searchVal: string) => Promise<void>;
    searchFieldPlaceHolderText: string;
}

const useStyles = makeStyles((theme) => ({
    searchContainer: {
        marginBottom: theme.spacing(1),
    },
    searchBox: {
        width: '90%'
    }
}));

export const OperatorSearchField: React.FunctionComponent<OperatorSearchFieldProps> = observer((props) => {
    const {searchFunction, searchFieldPlaceHolderText} = props
    const classes = useStyles();

    const [searchFieldValue, setSearchFieldValue] = React.useState<string>("");
    const [isFetching, setIsFetching] = React.useState(false);

    const handleChange = (e: any) => {
        setSearchFieldValue(e.target.value)
    }

    const handleSubmit = React.useCallback(async (e: SyntheticEvent) => {
        e.preventDefault();

        if(searchFieldValue.trim() === "") {
            return;
        }

        setIsFetching(true);

        await searchFunction(searchFieldValue)

        setSearchFieldValue("");
        setIsFetching(false);
    }, [searchFieldValue]);

    return (
        <PaddedPaper className={classes.searchContainer}>
            <form onSubmit={handleSubmit}>
                <Grid container justify="space-evenly">
                    <InputField label={searchFieldPlaceHolderText} className={classes.searchBox} value={searchFieldValue} onChange={handleChange} autoFocus/>
                    <Button type='submit' color='secondary' variant='contained' disabled={isFetching}>
                        {isFetching ? <CircularProgress /> : <Trans>Search</Trans>}
                    </Button>
                </Grid>
            </form>
        </PaddedPaper>
    )
});