import * as React from "react";
import {useState} from "react";
import {makeStyles} from "@material-ui/core";

type TextExpandProps = {
    content: string;
    limit: number;
    onShowMoreCallback?: () => void;
    onShowLessCallback?: () => void;
};

const useStyles = makeStyles((theme) => ({
    content: {
        whiteSpace: 'normal',
        overflowWrap: 'break-word'
    },
    onShowButton: {
        overflowWrap: 'normal',
        fontSize: '87.5%',
        fontWeight: 400,
        marginLeft: '0.5rem',
        color: 'blue',
        '&:hover': {
            cursor: 'pointer',
            opacity: 0.5,
            textDecoration: 'underline'
        }
    }
}));


export const TextExpand: React.FunctionComponent<TextExpandProps> = ({ content, limit, onShowMoreCallback, onShowLessCallback }) => {

    // truncates the text to a certain limit, followed by an ellipsis
    // offers a show more/less button that can be overwritten

    const classes = useStyles();

    const [showAll, setShowAll] = useState<boolean>(false);

    const validatedLimit = (limit < 0 ? 0 : limit);

    const onShowMore = onShowMoreCallback || (() => {

        setShowAll(true);
    });

    const onShowLess = onShowLessCallback || (() => {

        setShowAll(false);
    });

    // if the text is smaller than the limit,
    // no need to truncate or show button
    if (content.length <= validatedLimit) {

        return <div className={classes.content}>
            {content}
        </div>;
    }

    // the content is being fully shown
    // display a button to show less
    if (showAll) {

        return <div className={classes.content}>
            {content}
            <span className={classes.onShowButton} onClick={onShowLess}>Show&nbsp;less</span>
        </div>;
    }

    // the content is being truncated
    // show as much as you can followed by an ellipsis
    // display a button to show more
    const truncatedContent = content.substring(0, validatedLimit);

    return <div className={classes.content}>
        {truncatedContent}&hellip;
        <span className={classes.onShowButton} onClick={onShowMore}>Show&nbsp;more</span>
    </div>;
};
