import * as React from "react";
import {observer} from "mobx-react-lite";
import {Grid, makeStyles, Typography} from "@material-ui/core";
import {Help, Info} from "@material-ui/icons";
import {grey} from "@material-ui/core/colors";
import {t} from "@lingui/macro";
import {MachineTypeModel} from "../../../stores/MachineTypeStore";

const useStyles = makeStyles(theme => ({
    wrapper: {
        marginRight: theme.spacing(2)
    },
    infoIcon: {
        marginRight: theme.spacing(1),
        color: grey[600]
    },
    infoMessageWrapper: {
        marginLeft: theme.spacing(1),
        textAlign: 'center',
        width: '150px',
        height: '150px',
        color: grey[600],
        border: '1px solid',
        borderColor: grey[600]
    }
}));

type MachineTypeImageProps = {
    type: MachineTypeModel | undefined;
}

export const MachineTypeImage: React.FunctionComponent<MachineTypeImageProps> = observer(({ type }) => {
    const classes = useStyles()

    if(!type){
        return (
            <div className={classes.wrapper}>
                <Grid container className={classes.infoMessageWrapper} alignItems={'center'} direction={'column'} justifyContent={'center'}>
                    <Help fontSize={'large'} className={classes.infoIcon}/><Typography variant={'h6'}>{t`Machine Type Unknown`}</Typography>
                </Grid>
            </div>
        )
    }

    if(!type.image_url){
        return (
            <div className={classes.wrapper}>
                <Grid container className={classes.infoMessageWrapper} alignItems={'center'} direction={'column'} justifyContent={'center'}>
                    <Info fontSize={'large'} className={classes.infoIcon}/><Typography variant={'h6'}>{t`No Image`}</Typography>
                </Grid>
            </div>
        )
    }

    return (
        <div className={classes.wrapper}>
            <img src={`/img/machine/${type.image_url}`} alt={"machine_type_image"} width={150} height={150}/>
        </div>
    )
})

