import * as React from "react";
import {Container} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineStatesPanel} from "./panels/MachineStatesPanel";
import {makeStyles} from "@material-ui/core/styles";
import {JobStatesPanel} from "./panels/JobStatesPanel";
import {ErrorsPanel} from "./panels/ErrorsPanel";
import {EventsPanel} from "./panels/EventsPanel";
import {MaintenancePanel} from "./panels/MaintenancePanel";
import {CalibrationsPanel} from "./panels/CalibrationsPanel";
import {Moment} from "moment";
import {JobsInfoPanel} from "./panels/JobsInfoPanel";
import {TabsContainer} from "../generic/TabsContainer";
import {ProcessDataPanel} from "./panels/ProcessDataPanel";
import {MachineModel} from "../../stores/MachineStore";

type MachineDataViewProps = {
    model: MachineModel;
}

export type MachineDataViewPanelProps = {
    machine: MachineModel;
}

const useStyles = makeStyles((theme) => ({
    dataViewContainer: {
        marginTop: theme.spacing(1),
    }
}));

export const MachineDataView: React.FunctionComponent<MachineDataViewProps> = observer((props) => {
    const {model} = props;
    const classes = useStyles();

    return (
        <Container className={classes.dataViewContainer} maxWidth='xl'>
                <TabsContainer
                    variant="scrollable"
                    scrollButtons="auto"
                    tabs={[
                        {
                            label: t`Jobs`,
                            component: <JobsInfoPanel machine={model}/>,
                            defaultTab: true
                        },
                        {
                            label: t`Machine States`,
                            component: <MachineStatesPanel machine={model}/>
                        },
                        {
                            label: t`Job States`,
                            component: <JobStatesPanel machine={model}/>
                        },
                        {
                            label: t`Errors`,
                            component: <ErrorsPanel machine={model}/>
                        },
                        {
                            label: t`Events`,
                            component: <EventsPanel machine={model}/>
                        },
                        {
                            label: t`Maintenance`,
                            component: <MaintenancePanel machine={model}/>
                        },
                        {
                            label: t`Calibration`,
                            component: <CalibrationsPanel machine={model}/>
                        },
                        {
                            label: t`Process Data`,
                            component: <ProcessDataPanel machine={model}/>
                        }
                    ]}
                />
        </Container>
    );
});