import * as React from "react";
import {observer} from "mobx-react-lite";
import {period} from "./PeriodFilterButtons";
import {ModelTable} from "@rx-suite/ui";
import {Column, Filter, SortingRule} from "react-table";
import {DataStore, Model} from "@rx-suite/data";
import {Component} from "react";
import {MachineModel} from "../../stores/MachineStore";

type MachineDataViewTableProps = {
    machine: MachineModel;
    store: DataStore<Model>;
    columns: Column[];
    periodFilterNum: number;
    subComponent?: (original: Model) => Component | undefined;
    defaultSorted?: SortingRule;
    defaultFiltered?: Filter[];
}


export const MachineDataViewTable: React.FunctionComponent<MachineDataViewTableProps> = observer(({machine, store, columns, periodFilterNum, subComponent, defaultSorted, defaultFiltered}) => {

    const sorted = defaultSorted ?
        defaultSorted :
        [{id: "time", desc: true}]

    const filtered = defaultFiltered
        ? defaultFiltered.slice()
        : []
    ;

    // Adding a push with the period and machine sn since all filters will have it, might as well not require it from custom forms
    filtered.push({id: "sn", value: machine.sn});
    filtered.push({id: "period", value: period[periodFilterNum].key});

    return (
        <div>
            <ModelTable
                suppressWrapper
                store={store}
                columns={columns}
                pageSize={100}
                SubComponent={subComponent ? ({original}) => { return subComponent(original); } : undefined}
                defaultSorted={sorted}
                defaultFiltered={filtered}
                replacementActions={{
                    Delete: () => null
                }}
            />
        </div>
    );
});