import * as React from "react";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {MachineDataViewTab} from "../MachineDataViewTab";
import {MachineStateStore} from "../../../stores/MachineStateStore";
import {makeFormattedDateTimeColumn, SelectField} from "@rx-suite/ui";
import {Filter, ReactTableFunction} from "react-table";
import {MachineDataViewPanelProps} from "../MachineDataView";


export const MachineStatesPanel: React.FunctionComponent<MachineDataViewPanelProps> = observer((props) => {
    const {machine} = props;
    const store = MachineStateStore;

    const stateFilterOptions = [
        {label: t`on`, value: 0},
        {label: t`notready`, value: 1},
        {label: t`ready`, value: 2},
        {label: t`waitingforjobs`, value: 3},
        {label: t`processing`, value: 4},
        {label: t`maintenance`, value: 5},
        {label: t`error`, value: 6},
        {label: t`halt`, value: 7},
        {label: t`estop`, value: 8},
        {label: t`setup`, value: 9},
        {label: t`off`, value: 10},
        {label: t`all`, value: ""}
    ]

    const columns = [
        {
            Header: t`Machine States`, columns: [
                {
                    Header: t`State`,
                    id: 'state',
                    accessor: 'state',
                    filterable: true,
                    Filter: ({ filter, onChange }: { filter: Filter, onChange: ReactTableFunction}) => (
                        <SelectField
                            options={stateFilterOptions}
                            onChange={(name, value) => onChange(value)}
                            value={filter ? filter.value : ""}
                        />
                    )
                },
                makeFormattedDateTimeColumn("time", t`Date - Time`, "dateTime")
            ]
        }];

    return (
        <MachineDataViewTab
            columns={columns}
            machine={machine}
            enabledKey={'machine_state_enabled'}
            tabName={'Machine State'}
            store={store}
            exportedFileName={'MachineStates.csv'}
            exportEndpoint={'machine_states'}
        />
    );
});