import * as React from "react";
import {observer} from "mobx-react-lite";
import {ScannerField, SelectField, WorkstationGenericWrapper,} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Grid} from "@material-ui/core";
import {MachineModel, MachineStore} from "../../stores/MachineStore";
import {ProcessBookingWorkstationState} from "../../pages/process_booking_workstations/ProcessBookingWorkstation";
import Box from "@material-ui/core/Box";

type ProcessBookingWorkstationJobSearchFieldProps = {
   machineSn: string | null;
   machines: MachineModel[];
   setMachineSn: React.Dispatch<React.SetStateAction<string>>;
   workstationState: ProcessBookingWorkstationState;
}

export const ProcessBookingWorkstationMachineSearchField: React.FunctionComponent<ProcessBookingWorkstationJobSearchFieldProps> = observer((props) => {
    const {machineSn, machines, setMachineSn, workstationState} = props;


    const inputRef = React.useRef<HTMLInputElement>();

    React.useEffect(() => {
        if(workstationState == 'scan_sn' && inputRef.current){
            inputRef.current.focus();
        }
    }, [inputRef.current, workstationState]);


    const handleChange = (e: any) => {
        const val = e.target.value;
        setMachineSn(val);
    };

    const machineOptions = React.useMemo(() => {
        const options = machines.map((machine) => {
            return {label: machine.extendedName, value: machine.sn as string}
        });

        options.unshift({label: "none", value: ""});

        return options;
    }, [MachineStore.models]);

    const selectOnChange = React.useCallback((name, value) => {
        setMachineSn(value);
    }, []);

    return (
       <Grid container spacing={2}>
           <Grid item xs={7} md={10}>
               <ScannerField
                   inputConfig={{
                       label: t`Machine Serial Number`,
                       value: machineSn,
                       onChange: handleChange,
                       disabled: workstationState === 'submitting'
                   }}
                   scanConfig={{
                       onComplete: () => {},
                       onPartial: () => {},
                       minLength: 3,
                       averageWaitTime: 20
                   }}
                   inputRefOverride={inputRef}
                   global={false}
               />
           </Grid>
           <Grid item xs={5} md={2}>
               <Box pl={1}>
                   <SelectField
                       label={t`Machine Name`}
                       options={machineOptions}
                       onChange={selectOnChange}
                       value={machineSn}
                   />
               </Box>
           </Grid>
       </Grid>
    )
})