import * as React from 'react';
import { Model } from '@rx-suite/data';
import {observer} from "mobx-react-lite";
import {ModelForm, ModelInput} from '@rx-suite/ui';
import {TabsContainer} from "../../../components/generic/TabsContainer";
import {t} from "@lingui/macro"
import {ExternalForwardingEndpointsTab} from "../../../components/data_forwarding_external_targets/ExternalForwardingEndpointsTab";
import {ExternalForwardingMachinesTab} from "../../../components/data_forwarding_external_targets/ExternalForwardingMachinesTab";
import Box from "@material-ui/core/Box";

type MachineDataPushTargetFormProps = {
  model: Model
}

export const ForwardingTargetsExternalForm: React.FunctionComponent<MachineDataPushTargetFormProps> = observer(({ model }) => {
    return(
        <ModelForm model={model} suppressMakeCopy suppressImportExport>
            <ModelInput name={'name'} />
            <ModelInput name={'base_url'} />
            <Box mt={1}>
                <TabsContainer
                    variant="scrollable"
                    scrollButtons="auto"
                    tabs={[
                        {
                            label: t`Endpoints`,
                            component: <ExternalForwardingEndpointsTab/>,
                            defaultTab: true
                        },
                        {
                            label: t`Machines`,
                            component: <ExternalForwardingMachinesTab/>,
                            disabled: model.isNew
                        }
                    ]}
                />
            </Box>
        </ModelForm>
    )
})