import * as React from 'react';
import {MachineStore} from "../../../stores/MachineStore";
import {MachineForm} from "./MachineForm";
import {ArchiveButton} from "../../../components/machine/settings_table/ArchiveButton";
import {ToggleArchivedButton} from "../../../components/machine/settings_table/ToggleArchivedButton";
import {RestoreButton} from "../../../components/machine/settings_table/RestoreButton";
import {BreadModel, formatters, makeColumn} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Check, Clear} from "@material-ui/icons";
import {green, red} from "@material-ui/core/colors";
import {observer} from "mobx-react-lite";
import {MachineGroupStore} from "../../../stores/MachineGroupStore";
import {MachineTypeStore} from "../../../stores/MachineTypeStore";
import {useMachineGroupColumn} from "../../../hooks/table_columns/useMachineGroupColumn";
import {useMachineTypeColumn} from "../../../hooks/table_columns/useMachineTypeColumn";

export const MachinesBreadModel = observer(() => {
    const columns = React.useMemo(() => {
        const cols = [
            makeColumn('name', t`Name`, "string"),
            makeColumn('sn', t`Serial Number`, "string"),
            useMachineTypeColumn(),
            useMachineGroupColumn(),
            makeColumn('is_conveyor_machine', t`Used in Routing?`, "boolean",
                formatters.boolean(
                    <Check style={{color: green[500]}}/>,
                    <Clear style={{color: red[500]}}/>)),
        ]

        return cols;
    }, [MachineStore.showArchived, MachineGroupStore.models, MachineTypeStore.models]);

    return(
        <BreadModel
            store={MachineStore}
            Form={MachineForm}
            columns={columns}
            tableProps={
                {
                    defaultPageSize: 100,
                    fixedHeight: false,
                    replacementActions: {
                        Delete: (cell) => cell.model.archived ? <RestoreButton model={cell.model}/> : <ArchiveButton model={cell.model}/>,
                        Read: () => null
                    },
                    preTableActions: <ToggleArchivedButton store={MachineStore}/>,
                    defaultFiltered: [{ id: 'archived', value: MachineStore.showArchived }],
                }
            }
        />
    )
});
