import * as React from 'react';
import {ProductionSettingStore} from "../../stores/ProductionSettingStore";
import {observer} from "mobx-react-lite";
import {Box, LinearProgress, Typography} from "@material-ui/core";
import {ModelCheckbox, ModelForm, ModelSelect} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {ModelInput} from "@rx-suite/ui/build";
export const ProductionSettingForm = observer(() => {

    const settings = ProductionSettingStore.selectedModel;
    if(!settings) return <LinearProgress />

    const handleToggleSimplifiedMachineStates = () => {
        const proceed = confirm(t`Changing this setting will overwrite the existing machine state colors. Proceed?`)

        if(!proceed){
            return;
        }

        settings.viewModel.simplified_machine_states = !settings.viewModel.simplified_machine_states;
    }

    return(
        <ModelForm model={settings} suppressMakeCopy suppressImportExport>
            <Typography variant={'h6'}>{t`Production Metrics`}</Typography>
            <ModelSelect name={'throughput_metric'}
                         options={
                             [
                                 {label: t`Lens`, value: 'lens'},
                                {label: t`Pairs`, value: 'pairs'}
                             ]
                         }
                         hint={
                                {
                                    title: t`Throughput Metric`,
                                    text: t`Indicates how jobs are to be counted for throughput calculations.`
                                }
                            }
            />
            <div>
                <ModelCheckbox
                    name={"simplified_machine_states"}
                    onChange={handleToggleSimplifiedMachineStates}
                    hint={
                        {
                            title: t`Simplified Machine States`,
                            text: t`When enabled, groups several machines states for reporting purposes.`
                        }
                    }/>
            </div>
            <Box mt={2}>
                <Typography variant={'h6'}>{t`Machine Production Targets`}</Typography>
            </Box>
            <ModelInput name={'machine_oee_target'}
                        type={'number'}
                        inputProps={
                            {
                                min: 1,
                                max: 100
                            }
                        }
            />
            <ModelInput name={'machine_utilization_target'}
                        type={'number'}
                        inputProps={
                            {
                                min: 1,
                                max: 100
                            }
                        }
            />
            <ModelInput name={'machine_uptime_target'}
                        type={'number'}
                        inputProps={
                            {
                                min: 1,
                                max: 100
                            }
                        }
            />
            <Box mt={2}>
                <Typography variant={'h6'}>{t`Other Metrics`}</Typography>
            </Box>
            <div>
                <ModelCheckbox
                    name={"is_eer_lab"}
                    disabled
                    hint={
                        {
                            title: t`Record Box Coater Performance Metrics`,
                            text: t`This setting is automatically enabled when Rx-EER is installed. This setting cannot be manually changed.`
                        }
                    }/>
            </div>
            <ModelInput name={'tx_tolerance'}/>
            <ModelInput name={'ty_tolerance'}/>
            <ModelInput name={'rz_tolerance'}/>
        </ModelForm>
    )
});
