import {attribute, DataStore, model, Model} from '@rx-suite/data';

import {t} from "@lingui/macro";
import * as yup from 'yup';

@model({
    transportLayer: "/api/jobs",
    permissionTarget: "Job",
    routingInfo: {
        create: "/orders/jobs/create",
        update: "/orders/jobs/:id/edit",
        read: "/orders/jobs/:id"
    }
})
export class JobModel extends Model {
    @attribute({
        label: t`Job Number`,
        validation: yup.string().required()
    })
    number: string = "";

    @attribute({
        label: t`Name`,
        validation: yup.string().nullable()
    })
    name: string = "";

    @attribute({
        label: t`Description`,
        validation: yup.string().nullable()
    })
    description: string = "";

    @attribute({
        label: t`Sequence Number`,
        validation: yup.string().nullable()
    })
    sequence_number: number = 0;

    @attribute({
        label: t`Priority`,
        validation: yup.number()
    })
    priority: number = 0;

    @attribute({
        label: t`Manufacturer`,
        validation: yup.string().nullable()
    })
    manufacturer: string = "";

    @attribute({
        label: t`Side`,
        validation: yup.string()
    })
    side: number = 0;

    @attribute({
        label: t`LMAT ID`,
        validation: yup.string().nullable()
    })
    lmat_id: string = "";

    @attribute({
        label: t`LMAT Type`,
        validation: yup.string().nullable()
    })
    lmat_type: string = "";

    @attribute({
        label: t`Batch Criteria`,
        validation: yup.string().nullable()
    })
    batch_criteria: string = "";

    @attribute({
        label: t`Template`,
        validation: yup.string().nullable()
    })
    template: string = "";

    @attribute({
        label: t`Job Type`,
        validation: yup.string().nullable()
    })
    job_type: string = "";

    @attribute({
        label: t`Enabled`,
        validation: yup.boolean()
    })
    enabled: boolean = true;

    @attribute({ label: t`Enabled`})
    expiry_date: Date = new Date();

    @attribute({ label: t`Status`})
    status: string = '';

    constructor() {
        super();
        super.setup();
    }
}

export const JobStore = JobModel.store as DataStore<JobModel>;
