import {attribute, DataStore, model, Model} from '@rx-suite/data';
import {t} from "@lingui/macro";
import * as yup from "yup";
import {action, computed} from "mobx";

@model({
    transportLayer: "/api/machine_data_push_targets",
    permissionTarget: 'MachineDataPushTarget',
    routingInfo: {
        create: "/settings/data_forwarding/external/create",
        update: "/settings/data_forwarding/external/:id/edit",
        read: "/settings/data_forwarding/external/:id"
    }
})
export class MachineDataPushTargetModel extends Model {

    @attribute({ label: t`Name`, validation: yup.string().required(t`Name is a required field`) })
    name = "";

    @attribute({ label: t`Base URL`, validation: yup.string().required(t`Target is a required field`).url() })
    base_url = "http://";

    @attribute({ label: t`Machine State URL Path`, validation: yup.string().nullable()})
    machine_state_path: string | null = null;

    @attribute({ label: t`Job State URL Path`, validation: yup.string().nullable()})
    job_state_path: string | null = null;

    @attribute({ label: t`Error URL Path`, validation: yup.string().nullable()})
    error_path: string | null = null;

    @attribute({ label: t`Event URL Path`, validation: yup.string().nullable()})
    event_path: string | null = null;

    @attribute({ label: t`Maintenance URL Path`, validation: yup.string().nullable()})
    maintenance_path: string | null = null;

    @attribute({ label: t`Calibration Data URL Path`, validation: yup.string().nullable()})
    calibration_path: string | null = null;

    @attribute({ label: t`Process Data URL Path`, validation: yup.string().nullable()})
    process_data_path: string | null = null;

    @attribute({label: t`Forward For...`})
    send_to: 'all_machines' | 'specific_machines' = 'all_machines';

    @attribute()
    machine_ids = [];

    constructor() {
        super();
        super.setup();
    }

    @computed
    get isAllMachines(): boolean {
        return this.send_to === 'all_machines';
    }

    @action.bound
    async addMachines(machine_ids: string[]): Promise<void> {
        this._state = 'updating';
        const resp = await MachineDataPushTargetStore.transportLayer.fetch(`/${this.id}/add_machines`, {
            method: 'put',
            headers: {
                "Content-Type": "application/json"
            },
            body: JSON.stringify({
                machine_data_push_target: {
                    machine_ids: machine_ids
                }
            })
        });
        const data = await resp.json();
        if(!resp.ok) {
           throw data;
        }
        this._state = 'done'
    }
}

export const MachineDataPushTargetStore = MachineDataPushTargetModel.store as DataStore<MachineDataPushTargetModel>;
