module MachineKpiCalculator
  class AbortTrends < TopAborts

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = AbortTrends.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :abort_count,
          handler: KpiTableHandler::MachineAbortCountKpiHandler,
          params: {
          }
        }
      ]
    end

    def build_results
      abort_codes = group_codes(data[:abort_count])

      # get top aborts from abort codes
      top_aborts = extract_top_x(abort_codes, 5)
      top_aborts = top_aborts.map {|e| e[:code]} # We only need the code of the top 5 aborts

      results = {}
      top_aborts.each do |abort|
        results[abort] = {}
      end

      data[:abort_count].each do |time, abort_data|
        results.keys.each { |abort_code| results[abort_code][time] = 0 }
        abort_data.each do |abort_code, val|
          next unless top_aborts.include?(abort_code)
          if as_percent?
            bucket_count_total = abort_data.values.sum
            abort_percentage = bucket_count_total == 0 ? 0 : ((val/bucket_count_total.to_f) * 100).round
            results[abort_code][time] = abort_percentage
          else
            results[abort_code][time] = val
          end
        end
      end

      results.transform_keys! {|code| resolve_abort_code(code)}

      results
    end

    def build_results_per_machine
      data[:abort_count]
    end
  end
end