module MachineKpiCalculator
  module BoxCoaterBatches
    class BatchCounts< MachineKpiCalculator

      include KpiHelpers
      include KpiTableHandler
      include IntervalBuilder

      class << self
        def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: {})
          kpi = BatchCounts.new(start_time, end_time, timeframe, machine_ids, options)
          kpi.run
        end
      end

      def initialize(start_time, end_time, timeframe, machine_ids, options)
        super(start_time, end_time, timeframe, machine_ids, options)
      end

      def handlers
        [
          {
            key: :batch_runs,
            handler: :batch_runs,
            params: {}
          }
        ]
      end

      def batch_runs
        MachineKpi.box_coater_batches_run_between(start_time, end_time, machine_ids, {})
      end

      def build_results
        batches_per_period = {}

        machine_ids.each do |machine_id|
          batches_per_period.merge!(group_machine_batches_per_period(machine_id)) do|k, val1 , val2|
            val1 + val2
          end
        end

        results = {}
        batches_per_period.each do |period, batches|
          results[period] = extract_period_information(batches)
        end

        results
      end

      def group_machine_batches_per_period(machine_id)
        machine_batches_per_period = {}
        batches = data[:batch_runs][machine_id]
        current_index = 0

        current_time = start_time

        while current_time <= end_time
          machine_batches_per_period[current_time] = []

          while current_index < batches.size
            if (batches[current_index][:end] - current_time).abs < timeframe_length
              machine_batches_per_period[current_time] << batches[current_index]
              current_index += 1
            else
              break
            end
          end

          current_time += timeframe_length
        end
        machine_batches_per_period
      end

      def extract_period_information(batches)
        total_in_period = 0
        aborted = 0
        finished = 0

        batches.each do |batch|
          total_in_period += batch[:duration]
          if batch[:state] == 'finished'
            finished += 1
          elsif batch[:state] == 'aborted'
            aborted += 1
          end
        end

        {
          finished: finished,
          aborted: aborted,
          durationOverPeriod: total_in_period
        }
      end

      def build_results_per_machine
        raise NotImplementedError
      end
    end
  end
end