module MachineKpiCalculator
  class ErrorTrends < TopErrors

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = ErrorTrends.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :error_count,
          handler: KpiTableHandler::MachineErrorCountKpiHandler,
          params: {
          }
        }
      ]
    end

    def build_results
      error_codes = group_codes(data[:error_count])

      # get top errors from error codes
      top_errors = extract_top_x(error_codes, 5)
      top_errors = top_errors.map {|e| e[:code]} # We only need the code of the top 5 errors

      results = {}
      top_errors.each do |error|
        results[error] = {}
      end

      data[:error_count].each do |time, err_data|
        results.keys.each { |err_code| results[err_code][time] = 0 }
        err_data.each do |err_code, val|
          next unless top_errors.include?(err_code)
          if as_percent?
            bucket_count_total = err_data.values.sum
            error_percentage = bucket_count_total == 0 ? 0 : ((val/bucket_count_total.to_f) * 100).round
            results[err_code][time] = error_percentage
          else
            results[err_code][time] = val
          end
        end
      end

      results.transform_keys! {|code| resolve_error_name(code)}

      results
    end

    def build_results_per_machine
      data[:error_count]
    end
  end
end