module MachineKpiCalculator
  class JobStateBreakdown < MachineKpiCalculator

    include KpiTableHandler

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options)
        kpi = JobStateBreakdown.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :job_states,
          handler: KpiTableHandler::JobStateCountKpiHandler,
          params: {
            job_states: %w[finished aborted started],
            use_pair: ProductionSetting.metric_is_pair?
          }
        }
      ]
    end

    def build_results
      adjust_for_pair if ProductionSetting.metric_is_pair?

      data[:job_states]
    end

    def build_results_per_machine
      adjust_for_pair if ProductionSetting.metric_is_pair?

      data[:job_states]
    end

    def adjust_for_pair
      data[:job_states].each do |machine_id, bucket|
        bucket.each do |time, job_states|
          job_states.each do |state, v|
            data[:job_states][machine_id][time][state]= v / 2
          end
        end
      end
    end
  end
end
