module MachineKpiCalculator
  class MeanTimeToRestore < MachineKpiCalculator

    include KpiTableHandler
    include MachineErrorHelpers
    include IntervalBuilder

    class << self
      def get_for_period_and_machines(start_time, end_time, timeframe, machine_ids, options: {aggregate_machines: true})
        kpi = MeanTimeToRestore.new(start_time, end_time, timeframe, machine_ids, options)
        kpi.run
      end
    end

    def initialize(start_time, end_time, timeframe, machine_ids, options)
      super(start_time, end_time, timeframe, machine_ids, options)
    end

    def handlers
      [
        {
          key: :machine_state_duration,
          handler: KpiTableHandler::MachineStateDurationKpiHandler,
          params: {
            machine_states: %w[error halt estop],
            sum_as: 'downtime'
          }
        },
        {
          key: :number_of_failures,
          handler: :get_number_of_failures,
          params: {}
        }
      ]
    end

    def get_number_of_failures
      result_builder(start_time, end_time) do |s_time, e_time|
        result = {}
        machine_ids.each do |machine_id|
          machine = Machine.find_by(id: machine_id)
          return 0 if machine.nil?
          result.merge!(machine.number_of_failures_between(s_time, e_time, self.timeframe)) {|k, a_val, b_val| a_val.merge(b_val) {|k, a, b| a + b} }
        end
        result
      end
    end

    # Returns the MTTR, calculated by the formula: MTTR = sum(Total day downtime / Total day NoF) / # of days
    # MTTR is expressed as a value in a number of seconds
    # Currently MTTR aggregates all the time buckets to a single value for the period
    def build_results
      downtime_buckets_by_date = filter_buckets_by_day(data[:machine_state_duration])
      nof_buckets_by_date = filter_buckets_by_day(data[:number_of_failures])
      date_keys = downtime_buckets_by_date.keys
      sum_of_downtime_nof = 0
      date_keys.each do |k|
        downtime_buckets = downtime_buckets_by_date[k] || {}
        nof_buckets = nof_buckets_by_date[k] || {}
        downtime = downtime_buckets.values.sum {|v| v[:downtime]}
        number_of_failures = [nof_buckets.values.map {|h| h[:failures]}.sum, 1].max # avoid division by zero case
        sum_of_downtime_nof += downtime / number_of_failures
      end
      return sum_of_downtime_nof if !date_keys || date_keys.length <= 0
      sum_of_downtime_nof / date_keys.length
    end
  end
end