module MachineErrorHelpers
  extend ActiveSupport::Concern
  include BucketCalculator

  def number_of_failures_between(start_time, end_time, timeframe, offset = false)
    failure_states = [:error, :halt, :estop]

    failure_buckets = {}
    # If start time starts at mid-hour, if we're not using offset we still want the buckets to start on the hour, not at the half hour
    bucket_start_time = if offset
                   start_time - start_time.beginning_of_hour == 30 ? start_time : start_time.advance(minutes: -30)
                 else
                   start_time - start_time.beginning_of_hour == 0 ? start_time : start_time.advance(minutes: -30)
                 end
    time_buckets = get_buckets(bucket_start_time, end_time, timeframe)
    time_buckets.each_with_index do |bucket, i|
      time = bucket[:start_time]
      # 1 second must be added to the end_time to mimic a bucket.
      # For example, its time would be 13:59:59, instead of 14:00:00
      next_time = i + 1 < time_buckets.length ? time_buckets[i + 1][:start_time] : end_time + 1.seconds
      failure_buckets[time] = {
        failures: MachineState.where(machine_sn: sn)
                              .where(MachineState.arel_table[:time].gteq(time < start_time ? start_time : time)
                                                 .and(MachineState.arel_table[:time].lt(next_time)))
                              .where(MachineState.arel_table[:state].in(failure_states))
                              .count
      }
    end
    failure_buckets
  end

  # This helper method groups buckets by date using the format 'YYYY-MM-DD'
  # Returns: {
  #   <date>: {
  #     <bucket_1>
  #     <bucket_2>,
  #     ...
  #   },
  #   ...
  # }
  def filter_buckets_by_day(buckets)
    buckets_by_day = {}
    buckets.each do |k, v|
      date = k.to_s.match(/([0-9]{4}-(0[0-9]|1[0-2])-([0-2][0-9]|3[0-1]))/)
      next if date.nil?
      date_key = date.to_s
      buckets_by_day[date_key] = {} if buckets_by_day[date_key].nil?
      buckets_by_day[date_key][k] = v
    end
    buckets_by_day
  end
end
