# -*- SkipSchemaAnnotations

module ErrorFilterMachineTypes
  module ArtDeblocker2
    extend ActiveSupport::Concern

    class_methods do
      def error_filters_data
        [
          {name: 'Watchdog error with pc', error_codes: '1000', behaviour: 'replace', replace_name: 'COMM: watchdog error with pc, communication not given any longer', group_code: '1000'},
          {name: 'PLC: MAIN AIR: no air pressure', error_codes: '1003', behaviour: 'use_as_is', group_code: '1003'},
          {name: 'PLC: MAIN AIR: weak air pressure', error_codes: '1004', behaviour: 'use_as_is', group_code: '1004'},
          {name: 'PLC: EMERGENCY STOP BUTTON: pressed', error_codes: '1005', behaviour: 'use_as_is', group_code: '1005'},
          {name: 'PLC: FRONT COVER: opened', error_codes: '1006', behaviour: 'replace', replace_name: 'FRONT COVER: opened', group_code: '1006'},
          {name: 'PLC: SERVICE DOOR: door 1 left side opened', error_codes: '1008', behaviour: 'use_as_is', group_code: '1008'},
          {name: 'PLC: SERVICE DOOR: door 3 left side opened', error_codes: '1010', behaviour: 'use_as_is', group_code: '1010'},
          {name: 'PLC: SERVICE DOOR: cabinet rotation opened', error_codes: '1011', behaviour: 'use_as_is', group_code: '1011'},
          {name: 'PLC: SERVICE DOOR: door front side opened', error_codes: '1012', behaviour: 'use_as_is', group_code: '1012'},
          {name: 'PLC: CONTROL AIR CPX: necessary air pressure not given', error_codes: '1017', behaviour: 'use_as_is', group_code: '1017'},
          {name: 'PLC: CONTROL AIR CPX PORTAL: necessary air pressure not given', error_codes: '1018', behaviour: 'use_as_is', group_code: '1018'},
          {name: 'PLC: OPERATION MODE: change to AUTOMATIC not possible', error_codes: '1041', behaviour: 'use_as_is', group_code: '1041'},
          {name: 'PLC: DRIVES ON/OFF: switch on drives not possible (check cover, doors and e-stop)', error_codes: '1051', behaviour: 'replace', replace_name: 'PLC: DRIVES ON/OFF: switch on drives not possible (check cover, doors and e-stop)', group_code: '1051'},
          {name: 'PLC: DRIVES ON: not possible, emergency stop button pressed', error_codes: '1052', behaviour: 'use_as_is', group_code: '1052'},
          {name: 'PLC: DRIVES ON: not possible, cover opened', error_codes: '1053', behaviour: 'use_as_is', group_code: '1053'},
          {name: 'PLC: DRIVES ON: not possible, servicedoor opened', error_codes: '1054', behaviour: 'use_as_is', group_code: '1054'},
          {name: 'PLC: DRIVES ON: not possible, main air not ok', error_codes: '1055', behaviour: 'use_as_is', group_code: '1055'},
          {name: 'PLC: DRIVES ON: not possible, station Portal not ready', error_codes: '1057', behaviour: 'use_as_is', group_code: '1057'},
          {name: 'PLC: DRIVES ON: not possible, station Drum not ready', error_codes: '1058', behaviour: 'use_as_is', group_code: '1058'},
          {name: 'PLC: DRIVES ON: not possible, station WaterUnit not ready', error_codes: '1060', behaviour: 'use_as_is', group_code: '1060'},
          {name: 'PLC: START AUTOMATION: not possible, machine not ready for automation', error_codes: '1090', behaviour: 'use_as_is', group_code: '1090'},
          {name: 'CONVEYOR: tray has not reached stopper at Pickup 1, check sensor/tray', error_codes: '1101', behaviour: 'replace', replace_name: 'CONVEYOR: tray has not reached stopper at Pickup 1, check sensor/tray', group_code: '1101'},
          {name: 'CONVEYOR: tray has not reached stopper at Pickup 2, check sensor/tray', error_codes: '1102', behaviour: 'replace', replace_name: 'CONVEYOR: tray has not reached stopper at Pickup 2, check sensor/tray', group_code: '1102'},
          {name: 'CONVEYOR: tray has not reached stopper at Place 1, check sensor/tray', error_codes: '1103', behaviour: 'replace', replace_name: 'CONVEYOR: tray has not reached stopper at Place 1, check sensor/tray', group_code: '1103'},
          {name: 'PLC: AUTOMATION ABORTED: machine in error state', error_codes: '1120', behaviour: 'use_as_is', group_code: '1120'},
          {name: 'PLC: TRAFFIC JAM', error_codes: '1230', behaviour: 'use_as_is', group_code: '1230'},
          {name: 'PLC: MOVING: error while coupling motor M2', error_codes: '2032', behaviour: 'use_as_is', group_code: '2032'},
          {name: 'PLC: MOVING: not possible, cylinder blocked lens not in upper position', error_codes: '2040', behaviour: 'use_as_is', group_code: '2040'},
          {name: 'PLC: MOVING: not possible, cylinder lens not in upper position', error_codes: '2041', behaviour: 'use_as_is', group_code: '2041'},
          {name: 'PLC: MOVING: not possible, cylinder blockpiece not in upper position', error_codes: '2042', behaviour: 'use_as_is', group_code: '2042'},
          {name: 'PLC: MOVING: not possible, gripper lens not in 90° position', error_codes: '2044', behaviour: 'use_as_is', group_code: '2044'},
          {name: 'PLC: MOVING: not possible, gripper blockpiece not in 90° position', error_codes: '2045', behaviour: 'use_as_is', group_code: '2045'},
          {name: 'GRIPPER BLOCKED LENS: no lens found', error_codes: '2106', behaviour: 'replace', replace_name: 'GRIPPER BLOCKED LENS: no lens found', group_code: '2106'},
          {name: 'PLC: GRIPPER LENS: no lens found', error_codes: '2107', behaviour: 'use_as_is', group_code: '2107'},
          {name: 'PLC: SWING GRIPPER LENS: 90° position not reached', error_codes: '2130', behaviour: 'use_as_is', group_code: '2130'},
          {name: 'PLC: SWING GRIPPER BLOCKED LENS: not allowed, portal position not above tray', error_codes: '2133', behaviour: 'use_as_is', group_code: '2133'},
          {name: 'PLC: CYLINDER BLOCKPIECE: not in position UP', error_codes: '2148', behaviour: 'use_as_is', group_code: '2148'},
          {name: 'PLC: CYLINDER LENS: not in position DOWN', error_codes: '2150', behaviour: 'use_as_is', group_code: '2150'},
          {name: 'PLC: CYLINDER BLOCKPIECE: not in position DOWN', error_codes: '2151', behaviour: 'use_as_is', group_code: '2151'},
          {name: 'PLC: RESET: movement of portal, error while moving', error_codes: '2162', behaviour: 'use_as_is', group_code: '2162'},
          {name: 'Axis: M1 General axis error', error_codes: '2800', behaviour: 'use_as_is', group_code: '2800'},
          {name: 'Axis: M1 Insufficient voltage on ACOPOS enable input', error_codes: '2806', behaviour: 'use_as_is', group_code: '2806'},
          {name: 'Axis: M2 General axis error', error_codes: '2820', behaviour: 'use_as_is', group_code: '2820'},
          {name: 'Axis: M2 Lag error', error_codes: '2824', behaviour: 'use_as_is', group_code: '2824'},
          {name: 'Axis: M2 Insufficient voltage on ACOPOS enable input', error_codes: '2826', behaviour: 'use_as_is', group_code: '2826'},
          {name: 'PLC: STOPPER SCAN POS1: not ready to move', error_codes: '3020', behaviour: 'use_as_is', group_code: '3020'},
          {name: 'PLC: STOPPER SCAN POS2: not ready to move', error_codes: '3021', behaviour: 'use_as_is', group_code: '3021'},
          {name: 'PLC: BELT MOTOR: not ready for reset', error_codes: '3050', behaviour: 'use_as_is', group_code: '3050'},
          {name: 'PLC: HOMING: not possible, encoder offset missing', error_codes: '4031', behaviour: 'use_as_is', group_code: '4031'},
          {name: 'PLC: HOMING: axis error while homing motor F2', error_codes: '4040', behaviour: 'use_as_is', group_code: '4040'},
          {name: 'PLC: MOVING: error while moving motor A', error_codes: '4063', behaviour: 'use_as_is', group_code: '4063'},
          {name: 'PLC: CHAMBER 1: switch on vacuum, vacuum not reached', error_codes: '4084', behaviour: 'use_as_is', group_code: '4084'},
          {name: 'PLC: CHAMBER 2: switch on vacuum, vacuum not reached', error_codes: '4085', behaviour: 'use_as_is', group_code: '4085'},
          {name: 'PLC: CHAMBER 3: switch on vacuum, vacuum not reached', error_codes: '4086', behaviour: 'use_as_is', group_code: '4086'},
          {name: 'PLC: CHAMBER 4: switch on vacuum, vacuum not reached', error_codes: '4087', behaviour: 'use_as_is', group_code: '4087'},
          {name: 'PLC: STATION LOAD: lens cylinder not in front position, check sensor', error_codes: '4106', behaviour: 'use_as_is', group_code: '4106'},
          {name: 'PLC: STATION LOAD: lens cylinder not in back position, check sensor', error_codes: '4107', behaviour: 'use_as_is', group_code: '4107'},
          {name: 'STATION DEBLOCKING: move/stop motor B2 not possible, motor not ready for command', error_codes: '4113', behaviour: 'replace', replace_name: 'STATION DEBLOCKING: move/stop motor B2 not possible, motor not ready for command', group_code: '4113'},
          {name: 'STATION DEBLOCKING: vacuum lost while deblocking process', error_codes: '4117', behaviour: 'replace', replace_name: 'STATION DEBLOCKING: vacuum lost while deblocking process', group_code: '4117'},
          {name: 'STATION DEBLOCKING: max deblocking time elapsed, lens not deblocked', error_codes: '4118', behaviour: 'replace', replace_name: 'STATION DEBLOCKING: max deblocking time elapsed, lens not deblocked', group_code: '4118'},
          {name: 'STATION DEBLOCKING: process aborted, synchronization with water unit failed', error_codes: '4123', behaviour: 'replace', replace_name: 'STATION DEBLOCKING: process aborted, synchronization with water unit failed', group_code: '4123'},
          {name: 'STATION DEBLOCKING: inflow water pressure under allowed min value', error_codes: '4129', behaviour: 'replace', replace_name: 'STATION DEBLOCKING: inflow water pressure under allowed min value', group_code: '4129'},
          {name: 'PLC: STATION CLEANING: process aborted, vacuum lost while cleaning', error_codes: '4135', behaviour: 'use_as_is', group_code: '4135'},
          {name: 'STATION CLEANING: inflow water pressure under min value', error_codes: '4137', behaviour: 'replace', replace_name: 'STATION CLEANING: inflow water pressure under min value', group_code: '4137'},
          {name: 'PLC: STATION DRYING: blockpiece detection, blockpiece missing', error_codes: '4153', behaviour: 'use_as_is', group_code: '4153'},
          {name: 'PLC: RESET: chamber 1 blockpiece detected', error_codes: '4170', behaviour: 'use_as_is', group_code: '4170'},
          {name: 'PLC: RESET: chamber 2 blockpiece detected', error_codes: '4171', behaviour: 'use_as_is', group_code: '4171'},
          {name: 'PLC: RESET: chamber 3 blockpiece detected', error_codes: '4172', behaviour: 'use_as_is', group_code: '4172'},
          {name: 'PLC: RESET: chamber 4 blockpiece detected', error_codes: '4173', behaviour: 'use_as_is', group_code: '4173'},
          {name: 'Axis: A General axis error', error_codes: '4800', behaviour: 'use_as_is', group_code: '4800'},
          {name: 'Axis: A Lag error', error_codes: '4804', behaviour: 'use_as_is', group_code: '4804'},
          {name: 'Axis: A Insufficient voltage on ACOPOS enable input', error_codes: '4806', behaviour: 'use_as_is', group_code: '4806'},
          {name: 'Axis: B2 General axis error', error_codes: '4820', behaviour: 'use_as_is', group_code: '4820'},
          {name: 'Axis: B2 Insufficient voltage on ACOPOS enable input', error_codes: '4826', behaviour: 'use_as_is', group_code: '4826'},
          {name: 'Axis: F2 General axis error', error_codes: '4840', behaviour: 'use_as_is', group_code: '4840'},
          {name: 'Axis: F2 Lag error', error_codes: '4844', behaviour: 'use_as_is', group_code: '4844'},
          {name: 'Axis: Y2 General axis error', error_codes: '4860', behaviour: 'use_as_is', group_code: '4860'},
          {name: 'Axis: B3 General axis error', error_codes: '4880', behaviour: 'use_as_is', group_code: '4880'},
          {name: 'Axis: B3 Insufficient voltage on ACOPOS enable input', error_codes: '4886', behaviour: 'use_as_is', group_code: '4886'},
          {name: 'Axis: C3 General axis error', error_codes: '4900', behaviour: 'use_as_is', group_code: '4900'},
          {name: 'Axis: C3 Insufficient voltage on ACOPOS enable input', error_codes: '4906', behaviour: 'use_as_is', group_code: '4906'},
          {name: 'Axis: E4 General axis error', error_codes: '4920', behaviour: 'use_as_is', group_code: '4920'},
          {name: 'PLC: HIGH PRESSURE PUMP: motor P1 already in standstill', error_codes: '5021', behaviour: 'use_as_is', group_code: '5021'},
          {name: 'PLC: SEWAGE TANK: upper limit reached', error_codes: '5047', behaviour: 'replace', replace_name: 'PLC: SEWAGE TANK: upper limit reached', group_code: '5047'},
          {name: 'PLC: SEWAGE TANK: sensor for boost pumping not gone within time', error_codes: '5048', behaviour: 'use_as_is', group_code: '5048'},
          {name: 'WATER INFLOW PRESSURE: actual pressure below limit', error_codes: '5230', behaviour: 'replace', replace_name: 'PLC: SEWAGE TANK: upper limit reached', group_code: '5230'},
          {name: 'Axis: P1 General axis error', error_codes: '5800', behaviour: 'use_as_is', group_code: '5800'},
          {name: 'Axis: P1 Insufficient voltage on ACOPOS enable input', error_codes: '5806', behaviour: 'use_as_is', group_code: '5806'},
          {name: 'Axis: P2 General axis error', error_codes: '5820', behaviour: 'use_as_is', group_code: '5820'},
          {name: 'Axis: P2 Insufficient voltage on ACOPOS enable input', error_codes: '5826', behaviour: 'use_as_is', group_code: '5826'},
          {name: 'Could not scan job ticket', error_codes: '6105', behaviour: 'use_as_is', group_code: '6105'},
          {name: 'Could not get data from host', error_codes: '6106', behaviour: 'use_as_is', group_code: '6106'},
          {name: 'Could not connect to ReUse-Server', error_codes: '6110', behaviour: 'use_as_is', group_code: '6110'},
          {name: 'Missing configuration data. Command not executeable!', error_codes: '6112', behaviour: 'use_as_is', group_code: '6112'},
          {name: 'Error occurred!', error_codes: '7906', behaviour: 'use_as_is', group_code: '7906'},
          {name: 'Host: TimeOut ACK !', error_codes: '350006', behaviour: 'use_as_is', group_code: '350006'},
          {name: 'Scanner: TimeOut data set !', error_codes: '350008', behaviour: 'use_as_is', group_code: '350008'},
          {name: 'Host: Job Number wrong / not available !', error_codes: '350011', behaviour: 'replace', replace_name: 'Host: Job Number wrong / not available !', group_code: '350011'},
          {name: 'Host: Cannot process job ! BLK TOO WARM', error_codes: '350014', behaviour: 'replace', replace_name: 'Host: Cannot process job ! BLK TOO WARM', group_code: '350014'},
          {name: 'Host: cannot connect', error_codes: '404574', behaviour: 'replace', replace_name: 'Host: cannot connect', group_code: '404574'},
          {name: 'Watchdog Error', error_codes: '410008', behaviour: 'replace', replace_name: 'Watchdog Error', group_code: '410008'},
          {name: 'PVI Error', error_codes: '410000', behaviour: 'replace', replace_name: 'PVI Error', group_code: '410000'},
          {name: 'PLC: Request denied', error_codes: '410010', behaviour: 'replace', replace_name: 'PLC: Request denied', group_code: '410010'}
        ]
      end
    end
  end
end

