# == Schema Information
#
# Table name: kpi_machine_state_durations
#
#  id             :bigint           not null, primary key
#  dirty          :boolean          default(FALSE)
#  error          :decimal(10, 3)   default(0.0)
#  estop          :decimal(10, 3)   default(0.0)
#  halt           :decimal(10, 3)   default(0.0)
#  maintenance    :decimal(10, 3)   default(0.0)
#  notready       :decimal(10, 3)   default(0.0)
#  off            :decimal(10, 3)   default(0.0)
#  on             :decimal(10, 3)   default(0.0)
#  processing     :decimal(10, 3)   default(0.0)
#  ready          :decimal(10, 3)   default(0.0)
#  setup          :decimal(10, 3)   default(0.0)
#  time           :datetime         not null
#  waitingforjobs :decimal(10, 3)   default(0.0)
#  machine_id     :bigint
#
# Indexes
#
#  index_kpi_machine_state_durations_on_machine_id   (machine_id)
#  kpi_machine_state_duration_uniq_time_per_machine  (time,machine_id) UNIQUE
#
# Foreign Keys
#
#  fk_rails_...  (machine_id => machines.id) ON DELETE => cascade
#
class KpiMachineStateDuration < ApplicationRecord
  belongs_to :machine

  def should_archive?
    false
  end

  def as_cache_entry
    {
      time: time,
      machine_id: machine_id,
      on: on,
      notready: notready,
      ready: ready,
      waitingforjobs: waitingforjobs,
      processing: processing,
      maintenance: maintenance,
      error: error,
      halt: halt,
      estop: estop,
      setup: setup,
      off: off
    }
  end

  def self.backwards_cache_entry_calculation(entry)
    start_time = entry[:time]
    end_time = start_time + 30.minutes
    machine_id = entry[:machine_id]

    machine = Machine.where(id: machine_id).first
    machine.build_machine_state_duration_kpi_buckets(start_time, end_time)
  end
end
