# == Schema Information
#
# Table name: manufacturing_processes
#
#  id                       :bigint           not null, primary key
#  enabled                  :boolean
#  lead_time                :integer
#  name                     :string(4000)
#  planned_quantity         :integer
#  quantity_production_time :integer
#  setup_time               :integer
#  created_at               :datetime         not null
#  updated_at               :datetime         not null
#
class ManufacturingProcess < ApplicationRecord
  has_many :job_processes
  has_many :jobs, through: :job_processes
  has_many :machines, through: :job_processes
  has_many :job_manufacturing_processes
  has_many :jobs_through_man_proc, through: :job_manufacturing_processes, class_name: "Job"

  def self.get_by_job_and_name(job_id, name)
    return nil unless job_id
    return nil unless name
    process = ManufacturingProcess
                .joins(:job_manufacturing_processes)
                .where(job_manufacturing_processes: { job_id: job_id })
                .where("LOWER(name) = ?", name.downcase)
                .first
    if process.nil?
      process = ManufacturingProcess.new(name: name)
      process.job_manufacturing_processes.build(job_id: job_id)
      process.save!
    end
    process
  end
end
