module ReportComponents
  class BoxCoaterYieldLine < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers

    def component_id
      'box_coater_yield_line'
    end

    def component_type
      'line'
    end

    def generate(args)
      @timeframe = KpiHelpers::Timeframe::DAY_BY_DAY if timeframe == KpiHelpers::Timeframe::HOUR_BY_HOUR
      result = MachineKpi.box_coater_yield_between(start_time, end_time, @timeframe, machine_ids, options: args)
      labels = []
      avg_value = result.values.sum / result.size

      series = [
        {
          data: result.map do |time, value|
            labels << bucket_time_to_timeframe_label(time)
            value
          end,
          name: "Box Coater"
        }
      ]
      avg_series = Array.new(labels.size, avg_value)
      series << {
        data: avg_series,
        name: "Average (#{avg_value.round(2)}%)"
      }
      {
        series: series,
        labels: labels,
        colors: args[:colorize_series] ?
          color_for_series(series.size) :
          nil
      }
    end
  end
end
