module ReportComponents
  class MachineJobsProducedOverview < ReportComponent
    include DataHelpers
    include KpiHelpers

    include ReportComponentHelpers

    class InvalidTimeFrame < StandardError; end

    def component_id
      'machine_jobs_produced_overview'
    end

    def component_type
      'bar'
    end

    def generate(args)
      job_states = MachineKpi.job_state_breakdown_between(start_time, end_time, timeframe, machine_ids, options: args)

      abort_series = if args[:aggregate_machines]
        [build_series_for_kpi_bucket("Aborted Jobs", job_states, 'bar', :format_aborts)]
      elsif job_states.size == 1
        [build_series_for_kpi_bucket("Aborted Jobs", job_states[job_states.keys[0]], 'bar', :format_aborts)]
      else
        build_series_for_kpi_buckets_per_machine(job_states, 'bar', :format_aborts)
      end
      #aggregates machines states since our throughput is for all machines
      aggregated_for_throughput = job_states.reduce({}) {|res, (machine_id, buckets)| res.merge!(buckets) {|k,b,c| b.merge!(c) {|k,d,e| d+e}}}

      series = abort_series << build_series_for_kpi_bucket('Finished Jobs', aggregated_for_throughput, 'line', :format_throughput)
      {
        series: series,
        colors: args[:colorize_series] ?
          color_for_series(series.size) :
          nil
      }
    end

    def format_aborts(bucket_value)
      if bucket_value[:started] == 0
        return 100 if bucket_value[:aborted] > 0
        0
      else
        (bucket_value[:aborted] / bucket_value[:started].to_f) * 100
      end
    end

    def format_throughput(bucket_value)
      bucket_value[:finished]
    end
  end
end

