module ReportComponents
  class MachineTopErrorsBar < ReportComponent
    include ReportComponentHelpers
    include KpiHelpers

    def component_id
      'machine_top_errors'
    end

    def component_type
      'bar'
    end

    def generate(args)
      return set_no_data('This machine type does not collect errors.') unless machine_targets_collect_error(machine_ids)

      kpi_top_errors = MachineKpi.top_errors_between(start_time, end_time, Timeframe::ALL, machine_ids, options: args)
      categories = if args[:aggregate_machines]
                    kpi_top_errors.map {|kpi| kpi[:code]}
                  else
                    kpi_top_errors.values[0].map {|code, count| code}
                  end

      data = {
        categories: categories,
        series: if args[:aggregate_machines]
                  build_series_for_top_errors_aggregated(kpi_top_errors)
                else
                  build_series_for_top_errors_per_machine(kpi_top_errors)
                end
      }

      return set_no_data('No errors during reporting period') if data[:series].size == 0 || data[:series][0][:data].size == 0

      data[:colors] = color_for_series(kpi_top_errors.size) if args[:colorize_series]

      data
    end

    def build_series_for_top_errors_aggregated(top_errors_kpi)
      data = top_errors_kpi.map do |top_error_kpi|
        top_error_kpi[:count]
      end
      return [] if data.size == 0
      [{
         data: data
       }]
    end

    def build_series_for_top_errors_per_machine(top_errors_kpi)
      top_errors_kpi.map do |machine_id,errors|
        machine = Machine.find_by_id(machine_id)
        {
          name: machine&.ensured_name || machine_id,
          data: errors.map {|code, count| count}
        }
      end
    end
  end
end