class AddBlockCleanAndWasteCycles < ActiveRecord::Migration[6.0]
  def up
    block_wash_after_default = 30
    block_discard_after_default = 500

    create_table :block_reuse_settings do |t|
      t.boolean :enable_server
      t.integer :server_port

      t.integer :block_wash_after, default: block_wash_after_default
      t.integer :block_discard_after, default: block_discard_after_default

      t.string :last_server_message

      t.timestamps
    end

    create_table :block_reactivate_histories do |t|
      t.belongs_to :block, null: false, foreign_key: {on_delete: :cascade}
      t.string :action

      t.timestamps
    end

    add_column :blocks, :cycles_until_wash, :integer, default: block_wash_after_default
    add_column :blocks, :cycles_until_discard, :integer, default: block_discard_after_default

    # Update existing blocks

    # Due to a bug in migration with sharded DBS, we cannot use active record before an exec call, so update the blocks manually
    execute("update blocks set cycles_until_wash = #{block_wash_after_default} - usage_count, cycles_until_discard = #{block_discard_after_default} - usage_count")

=begin
    Block.reset_column_information
    Block.all.each do |b|
      b.cycles_until_wash = block_wash_after_default - b.usage_count
      b.cycles_until_discard = block_discard_after_default - b.usage_count
      b.save
    end
=end
  end

  def down
    drop_table :block_reuse_settings
    drop_table :block_reactivate_histories

    remove_column :blocks, :cycles_until_wash
    remove_column :blocks, :cycles_until_discard
  end
end
