class ChangeSettingsToDataArchiveSettings < ActiveRecord::Migration[6.1]
  def up
    create_table :data_archive_settings do |t|
      t.integer :job_max_age, default: 336
      t.integer :delete_count_order, default: 3
      t.integer :delete_count_job, default: 5
      t.integer :delete_count_machine_state, default: 4
      t.integer :delete_count_error, default: 3
      t.integer :delete_count_maintenance, default: 2
      t.integer :delete_count_event, default: 2
      t.integer :delete_count_calibration, default: 2
      t.integer :cycle_interval, default: 10
      t.timestamps
    end
    # Transferring the updated_at and created_at because the timestamps cant be null, and mssql and postgres have
    # different get time now methods
    sql = <<~SQL
      INSERT INTO data_archive_settings (job_max_age, created_at, updated_at)
      SELECT job_max_age, created_at, updated_at 
      FROM settings
    SQL
    execute(sql)
    remove_column :settings, :job_max_age
  end

  def down
    add_column :settings, :job_max_age, :integer, :default => 336
    sql = <<~SQL
      UPDATE settings 
      SET job_max_age=(
        SELECT job_max_age 
        FROM data_archive_settings
      )
    SQL
    execute(sql)
    drop_table :data_archive_settings
  end
end
